==> haskell-happstack-server-7.9.2.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.2.1
visibility:           public
id:                   happstack-server-7.9.2.1-Cns6sWgsSTU1EvPL5SmbuC
key:                  happstack-server-7.9.2.1-Cns6sWgsSTU1EvPL5SmbuC
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  5a982ac4e0d74c533a6664ae6ee82e2e
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.2.1-Cns6sWgsSTU1EvPL5SmbuC
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-20QKryWonJ0FfyBIVqw9dX
    blaze-html-0.9.2.0-7rraM1lSLOl2LrVAS4qxq6 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hslogger-1.3.1.2-CgDEthnG1ldCvUFV6hkiDU
    html-1.0.1.2-J6DAJfvF1D3ECsZlmS8hoI
    monad-control-1.0.3.1-9Q6yZyzqsWl7wMwMnI2eNb mtl-2.2.2
    network-3.1.4.0-29qUxJkoDip75hxElAm7gZ
    network-uri-2.6.4.2-2Sr7Eg9Bhz3KcJ8Mdx9CYP
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 sendfile-0.7.11.6-1ucUVnn1h9JLq7s61c85A5
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    system-filepath-0.4.14.1-9CDVQ1PBVUaJg5qDN6YAwP text-2.0.2
    threads-0.5.1.8-8fx6APski0IFfDG0TNT6zp time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-Lje61Sgnk77G867ddMqoaX
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm xhtml-3000.2.2.1
    zlib-0.6.3.0-LpsU7RxXEmX5AsdSWV7cLM

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-happstack-server-7.9.2.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-happstack-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.2.1
visibility:           public
id:                   happstack-server-7.9.2.1-IxzDbR8cgSv4n3p56Etaq7
key:                  happstack-server-7.9.2.1-IxzDbR8cgSv4n3p56Etaq7
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  6eb5c12517a9d9ab3ed2f9e2a6beb564
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/happstack-server-7.9.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.2.1-IxzDbR8cgSv4n3p56Etaq7
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    blaze-html-0.9.2.0-7T5tBdPknWXDUJ5NeSXWzj bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hslogger-1.3.1.2-HizOYagnRFdDuoLuue81te
    html-1.0.1.2-J6DAJfvF1D3ECsZlmS8hoI
    monad-control-1.0.3.1-Gw3XM64JSJ5ntrqlz8Emw mtl-2.2.2
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 sendfile-0.7.11.6-Bibct3x2BNY3gu4dxkQL8s
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    system-filepath-0.4.14.1-9LoFpwTndYr6M8lcRxwdbw text-2.0.2
    threads-0.5.1.8-7sNxsnzxzbJL9fT0UQQLC7 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm xhtml-3000.2.2.1
    zlib-0.6.3.0-DQJ3sjglCnhJjpkMXQsJJY

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
